==> modbus-1.0-7-src.zip: modbus/sci_gateway/c/sci_modbus_flush.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2011 - DIGITEO - Allan CORNET
 * Copyright (C) 2012 - Scilab Enterprises - Antoine ELIAS
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */
#include <errno.h>

#include "modbus.h"
#include "api_scilab.h"
#include "Scierror.h"
#include "MALLOC.h"
#include "localization.h"
/* ========================================================================== */
int sci_modbus_flush(char *fname, unsigned long fname_len)
{
    SciErr sciErr;
    int errsv = 0;

    modbus_t *pstrMod = NULL;
    int *piAddr1 = NULL;

    CheckInputArgument(pvApiCtx, 1, 1);
    CheckOutputArgument(pvApiCtx, 1, 2);

    sciErr = getVarAddressFromPosition(pvApiCtx, 1, &piAddr1);
    if (sciErr.iErr)
    {
        printError(&sciErr, 0);
        return 1;
    }

    if (!isPointerType(pvApiCtx, piAddr1))
    {
        Scierror(999, _("%s: Wrong type for input argument #%d: A pointer expected.\n"), fname, 1);
        return 1;
    }

    sciErr = getPointer(pvApiCtx, piAddr1, (void**)&pstrMod);
    if (sciErr.iErr)
    {
        printError(&sciErr, 0);
        return 1;
    }

    if (pstrMod)
    {
        int ret = 0;
        errno = 0;
        ret = modbus_flush(pstrMod);
        errsv = errno;
        errno = 0;
        if(ret == -1 && nbOutputArgument(pvApiCtx) != 2)
        {
            Scierror(999, "%s: %s\n", fname, modbus_strerror(errsv));
            return 1;
        }

        if (createScalarDouble(pvApiCtx, nbInputArgument(pvApiCtx) + 1, ret))
        {
            Scierror(999, _("%s: Memory error.\n"), fname);
            return 1;
        }

        if (createScalarDouble(pvApiCtx, nbInputArgument(pvApiCtx) + 2, errsv))
        {
            Scierror(999, _("%s: Memory error.\n"), fname);
            return 1;
        }

        AssignOutputVariable(pvApiCtx, 1) = nbInputArgument(pvApiCtx) + 1;
        AssignOutputVariable(pvApiCtx, 2) = nbInputArgument(pvApiCtx) + 2;
        ReturnArguments(pvApiCtx);
    }
    else
    {
        Scierror(999, _("%s: Invalid pointer #%d.\n"), fname, 1);
        return 1;
    }

    return 0;
}
/* ========================================================================== */

==> modbus-1.1-2-src.zip: modbus/sci_gateway/c/sci_modbus_flush.c <==
/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2011 - DIGITEO - Allan CORNET
 * Copyright (C) 2012 - Scilab Enterprises - Antoine ELIAS
 *
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */
#include <errno.h>

#include "modbus.h"
#include "api_scilab.h"
#include "Scierror.h"
#include "sci_malloc.h"
#include "localization.h"
/* ========================================================================== */
int sci_modbus_flush(char *fname, void * pvApiCtx)
{
    SciErr sciErr;
    int errsv = 0;

    modbus_t *pstrMod = NULL;
    int *piAddr1 = NULL;

    CheckInputArgument(pvApiCtx, 1, 1);
    CheckOutputArgument(pvApiCtx, 1, 2);

    sciErr = getVarAddressFromPosition(pvApiCtx, 1, &piAddr1);
    if (sciErr.iErr)
    {
        printError(&sciErr, 0);
        return 1;
    }

    if (!isPointerType(pvApiCtx, piAddr1))
    {
        Scierror(999, _("%s: Wrong type for input argument #%d: A pointer expected.\n"), fname, 1);
        return 1;
    }

    sciErr = getPointer(pvApiCtx, piAddr1, (void**)&pstrMod);
    if (sciErr.iErr)
    {
        printError(&sciErr, 0);
        return 1;
    }

    if (pstrMod)
    {
        int ret = 0;
        errno = 0;
        ret = modbus_flush(pstrMod);
        errsv = errno;
        errno = 0;
        if(ret == -1 && nbOutputArgument(pvApiCtx) != 2)
        {
            Scierror(999, "%s: %s\n", fname, modbus_strerror(errsv));
            return 1;
        }

        if (createScalarDouble(pvApiCtx, nbInputArgument(pvApiCtx) + 1, ret))
        {
            Scierror(999, _("%s: Memory error.\n"), fname);
            return 1;
        }

        if (createScalarDouble(pvApiCtx, nbInputArgument(pvApiCtx) + 2, errsv))
        {
            Scierror(999, _("%s: Memory error.\n"), fname);
            return 1;
        }

        AssignOutputVariable(pvApiCtx, 1) = nbInputArgument(pvApiCtx) + 1;
        AssignOutputVariable(pvApiCtx, 2) = nbInputArgument(pvApiCtx) + 2;
        ReturnArguments(pvApiCtx);
    }
    else
    {
        Scierror(999, _("%s: Invalid pointer #%d.\n"), fname, 1);
        return 1;
    }

    return 0;
}
/* ========================================================================== */
